@@ -41,7 +41,7 @@ sub grammar_regexp {
         comment        => qr{#(.*)},
         table          => qr{\[([^.\s\\\]]+(?:\.[^.\s\\\]]+)*)\]},
         array_of_table => qr{\[\[([^.\s\\\]]+(?:\.[^.\s\\\]]+)*)\]\]},
-        key            => qr{([^.\s\\]+)\s*=},
+        key            => qr{([^\s]+)\s*=},
         value          => {
             datetime => qr{([0-9]{4}-[0-9]{2}-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2}Z)},
             float    => qr{(-?[0-9]*\.[0-9]+)},
