@@ -2,8 +2,9 @@ package TOML::Parser::Util;
 use 5.008005;
 use strict;
 use warnings;
+use utf8;
 
-use Exporter 5.57 'import';
+use parent qw/Exporter/;
 our @EXPORT_OK = qw/unescape_str/;
 
 sub unescape_str {
@@ -20,9 +21,6 @@ sub unescape_str {
     $str =~ s{\\u([0-9A-Fa-f]{4})}{# unicode         (U+XXXX)
         chr hex $1
     }xmgeo;
-    $str =~ s{\\U([0-9A-Fa-f]{8})}{# unicode         (U+XXXXXXXX)
-        chr hex $1
-    }xmgeo;
 
     return $str;
 }
